uploads.Volume (Library volume) — amici1

# `uploads.Volume` (Library volume)

Volume(id, ref, root_dir, base_url, description)

Master tables : uploads.Volumes (Library volumes)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- Root directory (root_dir) : See `<lino.core.fields.CharField: root_dir>`.

- Base URL (base_url) : See `<lino.core.fields.CharField: base_url>`.

- Description (description) : See `<lino.core.fields.CharField: description>`.

- Name (name_column) : See `lino.modlib.uploads.models.Volume.name_column`.

- (None) (navigation_panel) : See `lino.modlib.uploads.models.Volume.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.uploads.models.Volume.overview`.

Referenced from ledger.Journal.uploads_volume, uploads.Upload.volume

## Database fields

Internal name | Verbose name | Help text
id | ID |
ref | Reference | The reference. This must be either empty or unique.
root_dir | Root directory |
base_url | Base URL |
description | Description |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |